<?php

use S123\Includes\Requests\S123_ApiRequest;

if (!defined('ABSPATH')) exit;

$invoiceData = $this->s123_fetchData(S123_ApiRequest::API_INVOICE_DATA_URL);

$nonce = wp_create_nonce('s123_security');
?>

<div class="tab-container">
    <div>
        <h3><?php echo __("Saskaita123.lt Invoice Settings", "s123-invoices") ?></h3>
    </div>

    <div class="info box">
        <?php echo __("Invoice is created immediately after the order is paid by the customer (status Completed).", "s123-invoices") ?>
    </div>

    <form method="post" id="invoiceSettingsSubmitForm">
        <div class="s123-form__group">
            <label for="series"><?php echo __("Series", "s123-invoices") ?></label>
            <select id="series" name="api_series" class="s123-form__control">
                <option hidden disabled selected><?php echo __("-- Select option --", "s123-invoices") ?></option>
                <?php if ($invoiceData["data"] && $invoiceData["data"]["series"]) : ?>
                    <?php foreach ($invoiceData["data"]["series"] as $datum) : ?>
                        <option
                                value="<?php echo esc_attr($datum["id"]); ?>"
                            <?php echo esc_attr($datum["id"]) === $this->s123_get_option("api_series") ? 'selected' : '' ?>
                        >
                            <?php echo esc_html($datum["title"]); ?>
                        </option>
                    <?php endforeach; ?>
                <?php endif; ?>
            </select>
        </div>

        <div class="s123-form__group">
            <label for="units"><?php echo __("Units", "s123-invoices") ?></label>
            <select id="units" name="api_units" class="s123-form__control">
                <option hidden disabled selected><?php echo __("-- Select option --", "s123-invoices") ?></option>
                <?php if ($invoiceData["data"] && $invoiceData["data"]["units"]) : ?>
                    <?php foreach ($invoiceData["data"]["units"] as $datum) : ?>
                        <option
                                value="<?php echo esc_attr($datum["id"]); ?>"
                            <?php echo esc_attr($datum["id"]) === $this->s123_get_option("api_units") ? 'selected' : '' ?>
                        >
                            <?php echo esc_html($datum["name"]); ?>
                        </option>
                    <?php endforeach; ?>
                <?php endif; ?>
            </select>
        </div>

        <?php if ($invoiceData["data"] && $invoiceData["data"]["banks"]) : ?>
            <div class="s123-form__group">
                <label><?php echo __("Banks", "s123-invoices") ?>:</label>
                <div class="s123_banks">
                    <?php foreach ($invoiceData["data"]["banks"] as $datum) : ?>
                        <div>
                            <label>
                                <input
                                        type="checkbox"
                                        value="<?php echo esc_attr($datum["id"]); ?>"
                                        name="api_banks[]"
                                    <?php
                                    if (is_array($this->s123_get_option("api_banks"))) {
                                        foreach ($this->s123_get_option("api_banks") as $bank) {
                                            if ($bank === $datum["id"]) echo 'checked';
                                        }
                                    }
                                    ?>
                                >
                            </label>
                            <?php echo esc_html($datum["title"]); ?>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        <?php endif; ?>

        <div class="activities-checkbox">
            <div class="s123-form__group" style="margin-bottom: 0;">
                <input
                        type="checkbox"
                        name="use_activities"
                        id="use_activities"
                    <?php echo $this->s123_get_option("use_activities") === true ? 'checked' : '' ?>
                        style="margin-top: 2px;"
                >
                <label for="use_activities" class="mx-2">
                    <?php echo __("Select activity type for individual activity", "s123-invoices") ?>
                </label>
            </div>

            <div class="s123-form__group margin-top" id="activities">
                <label for="activities"><?php echo __("Activities", "s123-invoices") ?></label>
                <select id="activities" name="api_activities" class="s123-form__control">
                    <option hidden disabled selected><?php echo __("-- Select option --", "s123-invoices") ?></option>
                    <?php if ($invoiceData["data"] && $invoiceData["data"]["activities"]) : ?>
                        <?php foreach ($invoiceData["data"]["activities"] as $datum) : ?>
                            <option
                                    value="<?php echo esc_attr($datum["id"]); ?>"
                                <?php echo esc_attr($datum["id"]) === $this->s123_get_option("api_activities") ? 'selected' : '' ?>
                            >
                                <?php echo esc_html($datum["name"]); ?>
                            </option>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </select>
            </div>
        </div>

        <div class="s123-form__group margin-top">
            <input
                    type="checkbox"
                    name="use_invoice_vats"
                    id="use_invoice_vats"
                <?php echo $this->s123_get_option("use_invoice_vats") === true ? 'checked' : '' ?>
                    style="margin-top: 2px;"
            >
            <label for="use_invoice_vats" class="mx-2">
                <?php echo __("Use Vats", "s123-invoices") ?>
            </label>
        </div>

        <div class="s123-form__group margin-top" id="invoice-vats">
            <label for="vats"><?php echo __("Vats", "s123-invoices") ?></label>
            <select id="vats" name="api_vats" class="s123-form__control">
                <option hidden disabled selected><?php echo __("-- Select option --", "s123-invoices") ?></option>
                <?php if ($invoiceData["data"] && $invoiceData["data"]["vats"]) : ?>
                    <?php foreach ($invoiceData["data"]["vats"] as $datum) : ?>
                        <option
                                value="<?php echo esc_attr($datum["id"]); ?>"
                            <?php echo esc_attr($datum["id"]) === $this->s123_get_option("api_vats") ? 'selected' : '' ?>
                        >
                            <?php echo esc_html($datum["vat_code"] . ' - ' . substr($datum['tariff'], 2) / 100 . '%'); ?>
                        </option>
                    <?php endforeach; ?>
                <?php endif; ?>
            </select>
        </div>

        <div class="s123-form__group">
            <label for="invoice_issued_by"><?php echo __("Invoice issued by", "s123-invoices") ?></label>
            <input
                    type="text"
                    class="s123-form__control"
                    id="invoice_issued_by"
                    name="invoice_issued_by"
                    value="<?php echo esc_attr($this->s123_get_option('invoice_issued_by')); ?>"
                    placeholder="<?php echo __("Provide your name or company name", "s123-invoices") ?>"
            >
        </div>

        <div class="s123-form__group margin-top activities-checkbox">
            <input
                    type="checkbox"
                    name="use_custom_inputs"
                    id="use_custom_inputs"
                <?php echo $this->s123_get_option("use_custom_inputs") === true ? 'checked' : '' ?>
                    style="margin-top: 2px;"
            >
            <label for="use_custom_inputs" class="mx-2">
                <?php echo __("Add custom inputs to checkout for clients to provide company requisites", "s123-invoices") ?>
            </label>
            <div style="margin-top: 6px;"><?php echo __("This is used to create invoices for companies", "s123-invoices") ?></div>
        </div>

        <input type="hidden" name="action" value="s123_submit_invoice_settings">
        <input type="hidden" name="s123_security" value="<?php echo esc_attr($nonce); ?>">
        <button type="submit" class="s123-btn s123-btn__primary"><?php echo __("Save", "s123-invoices") ?></button>
    </form>
</div>