<?php
/**
 * @link https://www.saskaita123.lt
 * @package Saskaita123Plugin
 *
 * Class Description: Provide API key input
 */

namespace S123\Includes\Pages;

use S123\Includes\Base\S123_BaseController;
use S123\Includes\Helpers\S123_ResponseHelpers;

if (!defined('ABSPATH')) exit;

class S123_ApiKey extends S123_BaseController
{
    public function s123_register()
    {
        add_action('wp_ajax_s123_submit_api_key', array($this, 's123_submit_api_key'));
    }

    /*
     * Validate and save provided api key
     */
    public function s123_submit_api_key()
    {
        if (isset($_POST['s123_security']) && wp_verify_nonce($_POST['s123_security'], 's123_security')) {
            $keys = ['api_key'];
            $data = [];

            foreach ($keys as $key) {
                $data[$key] = isset($_POST[$key]) ? sanitize_text_field(trim($_POST[$key])) : null;
            }

            if (!isset($_POST["api_key"]) || $_POST["api_key"] === '') {
                S123_ResponseHelpers::s123_sendErrorResponse(__('API Key cannot be empty!', 's123-invoices'));
            }

            $options = array_merge($this->s123_get_options(), $data);

            $this->s123_update_options($options);

            S123_ResponseHelpers::s123_sendSuccessResponse(__('API Key saved successfully!', 's123-invoices'));
        } else {
            S123_ResponseHelpers::s123_sendErrorResponse(__('Invalid secret key specified.', 's123-invoices'));
        }
    }
}