<?php
/**
 * @link https://www.saskaita123.lt
 * @package Saskaita123Plugin
 */

namespace S123\Includes\Pages;

use S123\Includes\Base\S123_BaseController;
use S123\Includes\Helpers\S123_ResponseHelpers;

if (!defined('ABSPATH')) exit;

class S123_InvoiceSettings extends S123_BaseController
{
    public function s123_register()
    {
        add_action('wp_ajax_s123_submit_invoice_settings', array($this, 's123_submit_invoice_settings'));
    }

    /*
     * Validate and save api settings
     */
    public function s123_submit_invoice_settings()
    {
        if (isset($_POST['s123_security']) && wp_verify_nonce($_POST['s123_security'], 's123_security')) {
            $keys = ['api_series', 'api_units', 'use_invoice_vats', 'api_vats', 'invoice_issued_by', 'use_activities', 'api_activities', 'use_custom_inputs'];
            $data = [];

            foreach ($keys as $key) {
                $data[$key] = isset($_POST[$key]) ? sanitize_text_field(trim($_POST[$key])) : null;
            }

            $apiBanks = [];
            if (isset($_POST['api_banks'])) {
                foreach ($_POST['api_banks'] as $bank) {
                    $apiBanks[] = sanitize_text_field(trim($bank));
                }
            }

            $data['api_banks'] = $apiBanks;
            $data['use_invoice_vats'] = isset($_POST['use_invoice_vats']);
            $data['use_activities'] = isset($_POST['use_activities']);
            $data['use_custom_inputs'] = isset($_POST['use_custom_inputs']);

            if (!isset($data['api_series'])) {
                S123_ResponseHelpers::s123_sendErrorResponse(__('Series cannot be empty.', 's123-invoices'));
            }

            if (!isset($data['api_units'])) {
                S123_ResponseHelpers::s123_sendErrorResponse(__('Units cannot be empty.', 's123-invoices'));
            }

            if ($data['use_invoice_vats'] && !isset($data['api_vats'])) {
                S123_ResponseHelpers::s123_sendErrorResponse(__('Vats cannot be empty.', 's123-invoices'));
            }

            if ($data['use_activities'] && !isset($data['api_activities'])) {
                S123_ResponseHelpers::s123_sendErrorResponse(__('Activity cannot be empty.', 's123-invoices'));
            }

            if (empty($data['invoice_issued_by'])) {
                S123_ResponseHelpers::s123_sendErrorResponse(__('Invoice issued by cannot be empty.', 's123-invoices'));
            }

            $options = array_merge($this->s123_get_options(), $data);

            $this->s123_update_options($options);

            S123_ResponseHelpers::s123_sendSuccessResponse(__('API Settings saved successfully!', 's123-invoices'));
        } else {
            S123_ResponseHelpers::s123_sendErrorResponse(__('Invalid secret key specified.', 's123-invoices'));
        }
    }
}