<?php
/**
 * @link https://www.saskaita123.lt
 * @package Saskaita123Plugin
 *
 * Class Description: Admin menu plugin settings tab
 */

declare(strict_types=1);

namespace S123\Includes\Pages;

use S123\Includes\Base\S123_BaseController;
use S123\Includes\Requests\S123_ApiRequest;

if (!defined('ABSPATH')) exit;

class S123_Settings extends S123_BaseController
{
    /**
     * API request object
     *
     * @var S123_ApiRequest
     */
    private $apiRequest;

    public function __construct()
    {
        parent::__construct();
        $this->apiRequest = new S123_ApiRequest();
    }

    public function s123_register()
    {
        add_action('admin_menu', array($this, 's123_add_plugin_admin_menu'));
        add_filter('plugin_action_links_' . $this->plugin_basename, array($this, 's123_settings_link'));
    }

    /*
     * Add plugin link to admin sidebar
     */
    public function s123_add_plugin_admin_menu()
    {
        add_submenu_page(
            'woocommerce',
            'Saskaita123.lt',
            'Saskaita123.lt',
            'manage_options',
            $this->plugin_name,
            array($this, 's123_display_plugin_setup_page')
        );
    }

    /*
     * Render plugin html
     */
    public function s123_display_plugin_setup_page()
    {
        require_once $this->plugin_path . 'admin/partials/s123-invoices-admin-dashboard.php';
    }

    /*
    * Plugin action links
    */
    public function s123_settings_link($links)
    {
        $action_links = array(
            'settings' => '<a href="admin.php?page=' . $this->plugin_name . '">' . __("Settings", "s123-invoices") . '</a>',
        );

        return array_merge($action_links, $links);
    }

    /*
    * Fetch data needed for API
    */
    public function s123_fetchData(string $url)
    {
        return $this->apiRequest->s123_makeGetRequest($url);
    }
}