<?php
/**
 * @link https://www.saskaita123.lt
 * @package Saskaita123Plugin
 *
 * Class Description: Requests to Saskaita123 API
 */

declare(strict_types=1);

namespace S123\Includes\Requests;

use S123\Includes\Base\S123_BaseController;

if (!defined('ABSPATH')) exit;

class S123_ApiRequest extends S123_BaseController
{
    /**
     * Stores API request header
     *
     * @var array
     */
    protected $apiRequestHeader = array();

    public const API_INVOICE_DATA_URL = 'https://app.saskaita123.lt/api/v1.0/invoice-data';
    public const API_INVOICE_URL = 'https://app.saskaita123.lt/api/v1.0/invoices';

    public function __construct()
    {
        parent::__construct();

        $this->apiRequestHeader = array(
            'headers' => array(
                'Authorization' => 'Bearer ' . $this->s123_get_option('api_key'),
                'Accept' => 'application/json',
                'Content-Type' => 'application/json'
            )
        );
    }

    public function s123_makeGetRequest(string $url)
    {
        $response = wp_remote_get($url, $this->apiRequestHeader);
        return json_decode(wp_remote_retrieve_body($response),true);
    }

    public function s123_makePostRequest(string $url, $data)
    {
        $body = array(
            'body' => json_encode($data)
        );
        $headers = array_merge($this->apiRequestHeader, $body);

        $response = wp_remote_post($url, $headers);
        return ['code' => wp_remote_retrieve_response_code($response), 'body' => json_decode(wp_remote_retrieve_body($response), true)];
    }
}