<?php
/**
 * @link https://www.saskaita123.lt
 * @package Saskaita123Plugin
 *
 * Class Description: Detect when user has purchased product
 */

namespace S123\Includes\Woocommerce;

use S123\Includes\Base\S123_BaseController;
use S123\Includes\Requests\S123_ApiRequest;

if (!defined('ABSPATH')) exit;

class S123_Product extends S123_BaseController
{
    /**
     * API request object
     *
     * @var S123_ApiRequest
     */
    private $apiRequest;

    public function __construct()
    {
        parent::__construct();
        $this->apiRequest = new S123_ApiRequest();
    }

    public function s123_register()
    {
        add_action('woocommerce_order_status_changed', array($this, 's123_createInvoice'), 99, 3);
    }

    /*
    * Create invoices after order status change
    */
    public function s123_createInvoice($order_id, $old_status, $new_status)
    {
        if ($new_status === 'completed') {
            if (!$order_id) {
                return;
            }

            // Allow code execution only once
            if (!get_post_meta($order_id, '_invoice_generated', true)) {

                // Get an instance of the WC_Order object
                $order = wc_get_order($order_id);
                $invoice = new S123_Invoice();

                if ($order->is_paid()) {
                    $response = $this->apiRequest->s123_makePostRequest(S123_ApiRequest::API_INVOICE_URL, $invoice->s123_buildInvoice($order));

                    // Flag the action as done
                    if ($response['code'] === 200) {
                        $order->update_meta_data('_invoice_generated', true);
                        $order->add_order_note(__('Invoice was generated at app.saskaita123.lt', 's123-invoices'), false, true);
                        $order->save();
                    } else {
                        $message = $this->errorMessage($response);
                        $order->add_order_note($message);
                    }
                }
            }
        }
    }

    /*
    * Format error message for order notes
    */
    private function errorMessage($response): string
    {
        $string = __('If you see this message, your invoice has not been generated, you can send this message to Saskaita123.lt support', 's123-invoices') . '. ';
        $errorMessage = $response['body']['error'];

        if ($errorMessage) {
            $string .= 'Error message: ' . $errorMessage['message'] . ' ';

            if ($errorMessage['errors']) {
                foreach ($errorMessage['errors'] as $key => $error) {
                    $string .= $key . ' => ' . json_encode($error, JSON_UNESCAPED_UNICODE) . ' ';
                }
            }
        } else {
            $string .= 'Error code: ' . $response['code'];
        }

        return $string;
    }
}